==> dif-database-repository-2.7.1-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/JasperReportTemplateParamFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link JasperReportTemplateParam}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class JasperReportTemplateParamFieldAttributes extends AbstractBeanAttributesDefinition{

    /** id (Database column: ID - ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDescription("ID")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** isEnabled (Database column: IS_ENABLED - Is enabled) */
    static public AttributeDefinition isEnabled =
        new AttributeDefinition("isEnabled")
                .setDescription("Is enabled")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("IS_ENABLED")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(boolean.class);

    /** parameterId (Database column: PARAMETER_ID - The parameter ID) */
    static public AttributeDefinition parameterId =
        new AttributeDefinition("parameterId")
                .setDescription("The parameter ID")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("PARAMETER_ID")
                .setMandatory(true)
                .setMaxSize(100)
                .setType(String.class);

    /** parameterName (Database column: PARAMETER_NAME - The parameter name) */
    static public AttributeDefinition parameterName =
        new AttributeDefinition("parameterName")
                .setDescription("The parameter name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("PARAMETER_NAME")
                .setMandatory(true)
                .setMaxSize(300)
                .setType(String.class);

    /** parameterOptionsList (Database column: PARAMETER_OPTIONS_LIST - The parameter options list (key value list)) */
    static public AttributeDefinition parameterOptionsList =
        new AttributeDefinition("parameterOptionsList")
                .setDescription("The parameter options list (key value list)")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("PARAMETER_OPTIONS_LIST")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** parameterOptionsSql (Database column: PARAMETER_OPTIONS_SQL - The parameter options SQL) */
    static public AttributeDefinition parameterOptionsSql =
        new AttributeDefinition("parameterOptionsSql")
                .setDescription("The parameter options SQL")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("PARAMETER_OPTIONS_SQL")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(String.class);

    /** parameterOptionsType (Database column: PARAMETER_OPTIONS_TYPE - The parameter options type (0=No options;1=Static list;2=SQL) */
    static public AttributeDefinition parameterOptionsType =
        new AttributeDefinition("parameterOptionsType")
                .setDescription("The parameter options type (0=No options;1=Static list;2=SQL")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("PARAMETER_OPTIONS_TYPE")
                .setMandatory(true)
                .setMaxSize(255)
                .setType(Long.class);

    /** jasperReportTemplate (Database column: TEMPLATE_ID - The template the param definition belongs to) */
    static public AttributeDefinition jasperReportTemplate =
        new AttributeDefinition("jasperReportTemplate")
                .setDescription("The template the param definition belongs to")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("TEMPLATE_ID")
                .setMandatory(true)
                .setMaxSize(255)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplate.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("description")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplate.class);

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(id.getName(),id);
        map.put(isEnabled.getName(),isEnabled);
        map.put(parameterId.getName(),parameterId);
        map.put(parameterName.getName(),parameterName);
        map.put(parameterOptionsList.getName(),parameterOptionsList);
        map.put(parameterOptionsSql.getName(),parameterOptionsSql);
        map.put(parameterOptionsType.getName(),parameterOptionsType);
        map.put(jasperReportTemplate.getName(),jasperReportTemplate);

        return map;
    }
}

==> dif-database-repository-2.7.3-5-sources.jar: pt/digitalis/dif/dem/managers/impl/model/data/JasperReportTemplateParamFieldAttributes.java <==
package pt.digitalis.dif.dem.managers.impl.model.data;

import pt.digitalis.utils.common.AttributeDefinition;
import pt.digitalis.dif.model.utils.AbstractBeanAttributesDefinition;

import java.sql.Timestamp;
import java.sql.Blob;
import java.util.Date;
import java.math.BigDecimal;

import java.util.Arrays;
import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import pt.digitalis.utils.common.collections.CaseInsensitiveHashMap;

import org.hibernate.Session;


/**
 *  Field definitions for data object {@link JasperReportTemplateParam}
 *
 * NOTE: This file is auto generated and will be overwritten in a future file generation.
 */
public class JasperReportTemplateParamFieldAttributes extends AbstractBeanAttributesDefinition{

    /** id (Database column: ID - ID) */
    static public AttributeDefinition id =
        new AttributeDefinition("id")
                .setDescription("ID")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setType(Long.class);

    /** isEnabled (Database column: IS_ENABLED - Is enabled) */
    static public AttributeDefinition isEnabled =
        new AttributeDefinition("isEnabled")
                .setDescription("Is enabled")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("IS_ENABLED")
                .setMandatory(true)
                .setMaxSize(1)
                .setTreatAsBoolean(true)
                .setBooleanFalseValue("0")
                .setBooleanTrueValue("1")
                .setLovFixedList(Arrays.asList(new String[]{"1","0"}))
                .setType(boolean.class);

    /** parameterId (Database column: PARAMETER_ID - The parameter ID) */
    static public AttributeDefinition parameterId =
        new AttributeDefinition("parameterId")
                .setDescription("The parameter ID")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("PARAMETER_ID")
                .setMandatory(true)
                .setMaxSize(100)
                .setType(String.class);

    /** parameterName (Database column: PARAMETER_NAME - The parameter name) */
    static public AttributeDefinition parameterName =
        new AttributeDefinition("parameterName")
                .setDescription("The parameter name")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("PARAMETER_NAME")
                .setMandatory(true)
                .setMaxSize(300)
                .setType(String.class);

    /** parameterOptionsList (Database column: PARAMETER_OPTIONS_LIST - The parameter options list (key value list)) */
    static public AttributeDefinition parameterOptionsList =
        new AttributeDefinition("parameterOptionsList")
                .setDescription("The parameter options list (key value list)")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("PARAMETER_OPTIONS_LIST")
                .setMandatory(false)
                .setMaxSize(4000)
                .setType(String.class);

    /** parameterOptionsSql (Database column: PARAMETER_OPTIONS_SQL - The parameter options SQL) */
    static public AttributeDefinition parameterOptionsSql =
        new AttributeDefinition("parameterOptionsSql")
                .setDescription("The parameter options SQL")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("PARAMETER_OPTIONS_SQL")
                .setMandatory(false)
                .setMaxSize(4000)
                .setType(String.class);

    /** parameterOptionsType (Database column: PARAMETER_OPTIONS_TYPE - The parameter options type (0=No options;1=Static list;2=SQL) */
    static public AttributeDefinition parameterOptionsType =
        new AttributeDefinition("parameterOptionsType")
                .setDescription("The parameter options type (0=No options;1=Static list;2=SQL")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("PARAMETER_OPTIONS_TYPE")
                .setMandatory(true)
                .setMaxSize(2)
                .setType(Long.class);

    /** jasperReportTemplate (Database column: TEMPLATE_ID - The template the param definition belongs to) */
    static public AttributeDefinition jasperReportTemplate =
        new AttributeDefinition("jasperReportTemplate")
                .setDescription("The template the param definition belongs to")
                .setDatabaseSchema("DIF")
                .setDatabaseTable("JASPER_REPORT_TEMPLATE_PARAM")
                .setDatabaseId("TEMPLATE_ID")
                .setMandatory(true)
                .setMaxSize(10)
                .setLovDataClass(pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplate.class)
                .setLovDataClassKey("id")
                .setLovDataClassDescription("description")
                .setType(pt.digitalis.dif.dem.managers.impl.model.data.JasperReportTemplate.class);

    /**
     * Gets description field.
     *
     * @return the description field
     */
    public static String getDescriptionField()
    {
        return null;
    }

    /**
    * Create definitions map map.
    *
    * @return the map
    */
    @Override protected CaseInsensitiveHashMap<AttributeDefinition> createDefinitionsMap(){
        CaseInsensitiveHashMap<AttributeDefinition> map = new CaseInsensitiveHashMap<AttributeDefinition>();
        map.put(id.getName(),id);
        map.put(isEnabled.getName(),isEnabled);
        map.put(parameterId.getName(),parameterId);
        map.put(parameterName.getName(),parameterName);
        map.put(parameterOptionsList.getName(),parameterOptionsList);
        map.put(parameterOptionsSql.getName(),parameterOptionsSql);
        map.put(parameterOptionsType.getName(),parameterOptionsType);
        map.put(jasperReportTemplate.getName(),jasperReportTemplate);

        return map;
    }
}
